## About

**django-zeropass allows users to login to your site without a password**.

A user enters their email address.
If a matching email is found in your `User` models, an email is
dispatched that contains a link with a token, that when clicked, is
verified and if successful the user is logged in.

Simples.

[![Build Status](https://travis-ci.org/[obscuremetaphor]/[django-zeropass].png)](https://travis-ci.org/[obscuremetaphor]/[django-zeropass])

[Read the documentation][0].

[0]: https://django-zeropass.obscuremetaphor.co.uk/
